<?xml version="1.0" encoding="UTF-8"?>
<!-- $Revision: 1.17 $ $Date: 2010/07/16 20:51:51 $ -->
<xsl:stylesheet
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:w="http://www.ws-i.org/2002/08/12/ProfileDoc-2.0.xsd"
 xmlns="http://www.w3.org/1999/xhtml"
 xmlns:h="http://www.ws-i.org/2002/08/12/ProfileMarkup-2.0.xsd"
 version="1.0"
 exclude-result-prefixes="w h"
>
	<xsl:strip-space elements="*"/>
	<xsl:output
	 method="html"
	 encoding="utf-8"
	 indent="yes"
	 doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"
	 doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
	 media-type="text/html"
	 omit-xml-declaration='yes'
	/>


    <xsl:variable name="has_statements" select="boolean(//w:statement)"/>
    <xsl:variable name="has_references" select="boolean(//w:references)"/>
    <xsl:variable name="has_bibrefs" select="boolean(//w:references/w:bibref)"/>
    <xsl:variable name="this_drafttype" select="//w:head/w:status"/>

	<xsl:variable name="profileref_this">
	  <xsl:choose>
		<xsl:when test="//w:head/w:defaultConformanceURI/@useTitle='true'">the <xsl:value-of select="//w:head/w:title"/><xsl:text> </xsl:text> <xsl:value-of select="//w:head/w:version"/></xsl:when>
		<xsl:otherwise>this Profile</xsl:otherwise>
	  </xsl:choose>
	</xsl:variable>

	<xsl:variable name="profileref_the">
	  <xsl:choose>
		<xsl:when test="//w:head/w:defaultConformanceURI/@useTitle='true'">the <xsl:value-of select="//w:head/w:title"/><xsl:text> </xsl:text> <xsl:value-of select="//w:head/w:version"/></xsl:when>
		<xsl:otherwise>the Profile</xsl:otherwise>
	  </xsl:choose>
	</xsl:variable>

	<xsl:template match="/">
		<html>
			<head>
				<title>
					<xsl:value-of select="//w:head/w:title"/> -
					Version <xsl:value-of select="//w:head/w:version"/>
					(<xsl:value-of select="//w:head/w:status"/>)
				</title>
				<style type="text/css">
                     body { color: black; background: white; font-family: sans-serif; margin: 16pt 24pt; }
                     dt { font-style: italic; padding-top: 0.5em; }
                     h4 { font-weight: normal; font-style: italic; font-size: 0.8em; margin-bottom: 0; }
                     .refinement { margin: 18pt 0em; }
                    .assertion-id { background-color: #faa; font-style: normal; padding: 0em 0.3em; }
                    .tanalysis-id { background-color: #faa; font-style: normal; padding: 0em 0.3em; }
                    .taglossary-id { background-color: #ccf; font-style: normal; padding: 0em 0.3em; }
                    .tbrnotes-id { background-color: #ccf; font-style: normal; padding: 0em 0.3em; }
                    .statement { font-style: italic; margin: 0.5em 5.5em; text-indent: -4em; }
                    .statement-id { background-color: #ffa; font-style: normal; padding: 0em 0.3em; }
					.statement-target { font-weight: bold; font-style: normal;  }
                    .statement-type { background-color: #ccf; font-style: normal; padding: 0em 0.3em; font-size: 0.7em; vertical-align: text-top; }
                    .compat-type { background-color: #cff; font-style: normal; padding: 0em 0.3em; font-size: 0.7em; vertical-align: text-top; }
                    .testable-type { background-color: #cfc; font-style: normal; padding: 0em 0.3em; font-size: 0.7em; vertical-align: text-top; }
                    .claim-type { background-color: pink; font-style: normal; padding: 0em 0.3em; font-size: 0.7em; vertical-align: text-top; }
                    .testref-type { font-style: normal; padding: 0em 0.3em; font-size: 0.7em; vertical-align: text-top; }
                    .relnotesref-type { background-color: #cff; font-style: normal; padding: 0em 0.3em; font-size: 0.7em; vertical-align: text-top; }
                    .glossaryref-type { background-color: #cff; font-style: normal; padding: 0em 0.3em; font-size: 0.7em; vertical-align: text-top; }
                    .statement-origin { background-color: #fcc; font-style: normal; padding: 0em 0.3em; font-size: 0.7em; vertical-align: text-top; }
                    .assertion { background-color: #eee; }
                    .tanalysis { background-color: #ffa; }
                    .taglossary { background-color: #ccf; }
                    .tablernotes { background-color: #ffa; }
                    .rationale { margin: 0.5em 0em;  }
                    .explanation { margin: 0.5em 0em; }
                    .definition { margin: 0.5em 5.5em;}
                    .explanation p, .rationale p { margin: 0.25em 0; }
                    .practice { background-color: green; }
                    .example { background-color: #eee; margin: 0.5em 2em; padding: 0.5em; }
                    .example-banner { margin: 0; }
                    .example pre { margin: 0; }
                    .correct, .incorrect { font-family: sans-serif; font-weight: bold; font-size: 0.9em; margin: 0; }
                    .correct { color: #090; }
                    .incorrect { color: #900; }
                    .specification { padding: 0.5em; background-color: #ffa; margin: 0.5em 2em; }
                    .ednote { margin: 1.2em; padding: 1.2em; background-color: #fcc; }
                    .note { background-color: #fcc; margin-left: 1.5em; }
                    .toc { margin-left: 2em; }
                    .subtoc { margin-left: 3em; }
                    .subsubtoc { margin-left: 4em; }
                    .chg { background-color: orange; text-decoration: underline; }
                    .add { background-color: green; text-decoration: underline; }
                    .del { background-color: red; text-decoration: line-through; }
                    @media print {
                        a.offsite:after { content: " [" attr(href) "] "; font-size: 85%; font-weight: lighter; }
                    }
                    [id]:hover:after { content: " #" attr(id) " "; font-size: 50%; color: #ccc; text-decoration: none; }
		        </style>
                <script type="text/javascript">
                function toggle(s) {
  var id = s.href.match(/#(\w.+)/)[1];
  var el = document.getElementById(id);
  if (el.style.display == 'block')
    el.style.display = 'none';
  else
    el.style.display = 'block';
}
                </script>
			</head>
			<body>
				<xsl:apply-templates/>
				<xsl:call-template name="trailer"/>
            </body>
        </html>
	</xsl:template>

	<xsl:template match="w:testAssertions">
	</xsl:template>
	
	<!-- header _______________________________________________________________ -->
	
	<xsl:template match="w:head">
	    <xsl:variable name="year" select="substring(w:cvsDate, 8, 4)"/>
	    <xsl:variable name="month" select="substring(w:cvsDate, 13, 2)"/>
	    <xsl:variable name="day" select="substring(w:cvsDate, 16, 2)"/>
		<div class="head">
			<p>
				<a href="http://www.ws-i.org/">
					<img src="http://www.ws-i.org/images/WS-I-logo.gif" height="88" width="107" border="0" alt="WS-I"/>
				</a>
			</p>
			<h1>
				<xsl:value-of select="w:title"/> Version <xsl:value-of select="w:version"/>
			</h1>
			<h2>
				<xsl:choose>
					<xsl:when test="w:status='ED'">Editors' Draft</xsl:when>
					<xsl:when test="w:status='WGD'">Working Group Draft</xsl:when>
					<xsl:when test="w:status='WGAD'">Working Group Approval Draft</xsl:when>
					<xsl:when test="w:status='BdAD'">Board Approval Draft</xsl:when>
					<xsl:when test="w:status='AD'">WS-I Approval Draft</xsl:when>
					<xsl:when test="w:status='Final'">Final Material</xsl:when>
				</xsl:choose>
				<xsl:if test="w:status='ED'"> - revision <xsl:value-of select="substring(w:webRevision, 14, 3)"/>
				</xsl:if> <!-- test="w:status='ED'" -->
				<xsl:if test="w:public='false'"> (Member-confidential)</xsl:if> <!-- test="w:public='false'" -->
			</h2>
			<h2>
				<xsl:value-of select="$year"/>-<xsl:value-of select="$month"/>-<xsl:value-of select="$day"/>
			</h2>
			<dl>
				<xsl:choose>
					<xsl:when test="w:public='false'">
						<dt>This revision:</dt>
						<dd>
							<a href="{w:memberLocationBase}{w:shortTitle}-{w:version}-{w:status}.html?versionId={w:webRevision}">
								<xsl:value-of select="w:memberLocationBase"/>
								<xsl:value-of select="w:shortTitle"/>-<xsl:value-of select="w:version"/>-<xsl:value-of select="w:status"/>.html?versionID=<xsl:value-of select="w:webRevision"/>
							</a>
						</dd>
						<dt>Latest revision:</dt>
						<dd>
							<a href="{w:memberLocationBase}{w:shortTitle}-{w:version}-{w:status}.html">
								<xsl:value-of select="w:memberLocationBase"/>
								<xsl:value-of select="w:shortTitle"/>-<xsl:value-of select="w:version"/>-<xsl:value-of select="w:status"/>.html
		                        </a>
						</dd>
					</xsl:when>
					<xsl:otherwise>
						<dt>This version:</dt>
						<dd>
							<a href="{w:publicLocationBase}{w:shortTitle}-{w:version}-{$year}-{$month}-{$day}.html">
								<xsl:value-of select="w:publicLocationBase"/><xsl:value-of select="w:shortTitle"/>-<xsl:value-of select="w:version"/>-<xsl:value-of select="$year"/>-<xsl:value-of select="$month"/>-<xsl:value-of select="$day"/>.html
							</a>
						</dd>
						<dt>Latest version:</dt>
						<dd>
							<a href="{w:publicLocationBase}{w:shortTitle}-{w:version}.html">
								<xsl:value-of select="w:publicLocationBase"/><xsl:value-of select="w:shortTitle"/>-<xsl:value-of select="w:version"/>.html
							</a>
						</dd>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:if test="w:status='Final'">
					<dt>Errata for this Version:</dt>
					<dd>
						<a href="{w:publicLocationBase}{w:shortTitle}-{w:version}-errata-{$year}-{$month}-{$day}.html">
								<xsl:value-of select="w:publicLocationBase"/><xsl:value-of select="w:shortTitle"/>-<xsl:value-of select="w:version"/>-errata-<xsl:value-of select="$year"/>-<xsl:value-of select="$month"/>-<xsl:value-of select="$day"/>.html
							</a>
					</dd>
				</xsl:if> <!-- test="w:status='Final'" -->
				<dt>Editors:</dt>
				<xsl:apply-templates select="w:editors/w:person"/>
				<dt>Administrative contact:</dt>
				<dd>
					<a href="mailto:secretary@ws-i.org">secretary@ws-i.org</a>
				</dd>
			</dl>
			<p class="copyright" id="copyright"> Copyright<xsl:text
			disable-output-escaping="yes"> &amp;#169; </xsl:text> 2002-<xsl:value-of select="$year"/> by
			<a href="http://www.ws-i.org/">The Web Services-Interoperability
			Organization</a> (<abbr title="Web Services Interoperability
			Organization">WS-I</abbr>) and Certain of its Members. All Rights
			Reserved.</p>
		</div>
		<hr/>
		<h2 id="abstract">Abstract</h2>
		<p>
			<xsl:value-of select="w:abstract"/>
		</p>
		<h2 id="status">Status of this Document</h2>
		<p>
			<xsl:choose>
				<xsl:when test="w:status='ED'"> This document is an editors'
				copy that has no official standing; it is not complete. Other
				documents may supersede this document. Discussion of this
				document takes place on the Member-only mailing list, <a
				href="mailto:{//w:discussionListLocation}"><xsl:value-of
				select="//w:discussionListLocation" /></a>. </xsl:when>

				<xsl:when test="w:status='WGD'"> This document is a Working
				Group Draft; it has been accepted by the Working Group as
				reflecting the current state of discussions. It is a work in
				progress, and should not be considered authoritative or final;
				other documents may supersede this document. </xsl:when>

				<xsl:when test="w:status='WGAD'"> This document is a Working
				Group Approval Draft; it is an intermediate document that has
				been approved for publication by the Working Group. It is a
				work in progress, and should not be considered as final; other
				documents may supersede this document. </xsl:when>

				<xsl:when test="w:status='BdAD'"> This document is a Board
				Approval Draft; it has been approved for publication by the
				Working Group, and is submitted for consideration by the Board
				of Directors, and for public comment. It is a work in
				progress, and should not be considered as final; other
				documents may supersede this document. </xsl:when>

				<xsl:when test="w:status='AD'"> This document is a WS-I
				Approval Draft; it has been approved for publication by the
				Board of Directors, and is submitted for consideration by the
				Membership, and for public comment. It is a work in progress,
				and should not be considered as final; other documents may
				supersede this document. </xsl:when>

				<xsl:when test="w:status='Final'"> This is a final
				specification. Please refer to the <a
				href="{//w:errataLocation}">errata</a>, which may include
				normative corrections to it. </xsl:when>
	        </xsl:choose>
		</p>
		<!-- p>Release notes related to the test material included in this document (see section 1.3) are available here:
		</p>

		<span class="relnotesref-type">
		<a onclick="javascript:toggle(this)">
		  <xsl:attribute name="href">
		    <xsl:text>#rn</xsl:text>
		    <xsl:value-of select="'ReleaseNotes'"/>
		  </xsl:attribute>
		  <xsl:text>TESTING-RELEASE-NOTES</xsl:text>
		</a>
	      </span>

	       <xsl:call-template name="displayReleaseNotes">
		 <xsl:with-param name="rnid" select="'ReleaseNotes'"/>
	      </xsl:call-template -->

		<xsl:if test="w:extraStatus">
			<p>
				<xsl:apply-templates mode="text" select="w:extraStatus"/>
			</p>
		</xsl:if> <!-- test="w:extraStatus" -->

		<h2 id="license">Notice</h2>
		<p>The material contained herein is not a license, either expressly or
		impliedly, to any intellectual property owned or controlled by any of
		the authors or developers of this material or WS-I. The material
		contained herein is provided on an "AS IS" basis and to the maximum
		extent permitted by applicable law, this material is provided AS IS
		AND WITH ALL FAULTS, and the authors and developers of this material
		and WS-I hereby disclaim all other warranties and conditions, either
		express, implied or statutory, including, but not limited to, any (if
		any) implied warranties, duties or conditions of merchantability, of
		fitness for a particular purpose, of accuracy or completeness of
		responses, of results, of workmanlike effort, of lack of viruses, and
		of lack of negligence. ALSO, THERE IS NO WARRANTY OR CONDITION OF
		TITLE, QUIET ENJOYMENT, QUIET POSSESSION, CORRESPONDENCE TO
		DESCRIPTION OR NON-INFRINGEMENT WITH REGARD TO THIS MATERIAL. </p>
		<p>IN NO EVENT WILL ANY AUTHOR OR DEVELOPER OF THIS MATERIAL OR WS-I
		BE LIABLE TO ANY OTHER PARTY FOR THE COST OF PROCURING SUBSTITUTE
		GOODS OR SERVICES, LOST PROFITS, LOSS OF USE, LOSS OF DATA, OR ANY
		INCIDENTAL, CONSEQUENTIAL, DIRECT, INDIRECT, OR SPECIAL DAMAGES
		WHETHER UNDER CONTRACT, TORT, WARRANTY, OR OTHERWISE, ARISING IN ANY
		WAY OUT OF THIS OR ANY OTHER AGREEMENT RELATING TO THIS MATERIAL,
		WHETHER OR NOT SUCH PARTY HAD ADVANCE NOTICE OF THE POSSIBILITY OF
		SUCH DAMAGES.</p>

		<h2 id="feedback">Feedback</h2>
		<xsl:choose>
				<xsl:when test="w:status='Final'">
					<p>If there are areas in this specification that could be
					clearer, or if errors or omissions are identified, WS-I
					would like to be notified in order to provide the best
					possible interoperability guidance.</p>
				</xsl:when>
				<xsl:otherwise>
					<p>The Web Services-Interoperability Organization (WS-I)
					would like to receive input, suggestions and other
					feedback ("Feedback") on this work from a wide variety of
					industry participants to improve its quality over time.
					</p>
				</xsl:otherwise>
			</xsl:choose>
			<p>By sending email, or otherwise communicating with WS-I, you (on
			behalf of yourself if you are an individual, and your company if
			you are providing Feedback on behalf of the company) will be
			deemed to have granted to WS-I, the members of WS-I, and other
			parties that have access to your Feedback, a non-exclusive,
			non-transferable, worldwide, perpetual, irrevocable, royalty-free
			license to use, disclose, copy, license, modify, sublicense or
			otherwise distribute and exploit in any manner whatsoever the
			Feedback you provide regarding the work. You acknowledge that you
			have no expectation of confidentiality with respect to any
			Feedback you provide. You represent and warrant that you have
			rights to provide this Feedback, and if you are providing Feedback
			on behalf of a company, you represent and warrant that you have
			the rights to provide Feedback on behalf of your company. You also
			acknowledge that WS-I is not required to review, discuss, use,
			consider or in any way incorporate your Feedback into future
			versions of its work. If WS-I does incorporate some or all of your
			Feedback in a future version of the work, it may, but is not
			obligated to include your name (or, if you are identified as
			acting on behalf of your company, the name of your company) on a
			list of contributors to the work. If the foregoing is not
			acceptable to you and any company on whose behalf you are acting,
			please do not provide any Feedback.</p>
			<p>Feedback on this document should be directed to <a
			href="mailto:{//w:commentListLocation}"><xsl:value-of
			select="//w:commentListLocation"/></a>.</p>
		<hr/>
		
		
		<h2 id="toc">Table of Contents</h2>
		<p class="toc">
		    <xsl:apply-templates select="//w:front/w:section" mode="toc"/>
		    <span class="subtoc"><xsl:value-of select="count(//w:front/w:section)"/>.<xsl:value-of select="count(//w:front/w:section[position()=last()]/w:subsection[@id != 'claimingconformance'])+1"/>. <a href="#conventions">Notational Conventions</a></span><br/>
            <xsl:if test="$has_statements">
                <span class="subtoc"><xsl:value-of select="count(//w:front/w:section)"/>.<xsl:value-of select="count(//w:front/w:section[position()=last()]/w:subsection[@id != 'claimingconformance'])+2"/>. <a href="#versioning">Profile Identification and Versioning</a></span><br/>
        		    <xsl:value-of select="count(//w:front/w:section)+1"/>. <a href="#conformance">Profile Conformance</a><br/>
        		    <span class="subtoc"><xsl:value-of select="count(//w:front/w:section)+1"/>.1. <a href="#conformance_requirements">Conformance Requirements</a></span><br/>
        		    <span class="subtoc"><xsl:value-of select="count(//w:front/w:section)+1"/>.2. <a href="#conformance_targets">Conformance Targets</a></span><br/>
        		    <span class="subtoc"><xsl:value-of select="count(//w:front/w:section)+1"/>.3. <a href="#conformance_scope">Conformance Scope</a></span><br/>
        		    <span class="subtoc"><xsl:value-of select="count(//w:front/w:section)+1"/>.4. <a href="#conformance_claims">Claiming Conformance</a></span><br/>
    		    </xsl:if> <!-- test="$has_statements" -->
            <xsl:apply-templates select="//w:body/w:section[@id != 'extra-appendix']" mode="toc">
                <xsl:with-param name="section_offset" select="2+$has_statements"/>
            </xsl:apply-templates>
          
            <xsl:if test="$has_references">
                Appendix A: <a href="#references">Referenced Specifications</a><br/>
                Appendix B: <a href="#points">Extensibility Points</a><br/>
                Appendix C: <a href="#normative_references">Normative References</a><br/>
            </xsl:if> <!-- test="$has_references" -->
            <xsl:if test="not($has_references)">
                Appendix A: <a href="normative_references">Normative References</a><br/>
            </xsl:if>
            <xsl:if test="//w:definedTerm/w:term">
                Appendix <xsl:value-of select="translate(($has_references*2)+2, '123456', 'ABCDEF')"/>: <a href="#defs">Defined Terms</a><br/>
            </xsl:if> <!-- test="//w:definedTerm/w:term" -->
            Appendix <xsl:value-of select="translate(($has_references*2)+boolean(//w:definedTerm/w:term)+2, '123456', 'ABCDEF')"/>: <a href="#acks">Acknowledgements</a><br/>
            <xsl:if test="//w:body/w:section[@id = 'extra-appendix']">
              Appendix <xsl:value-of select="//w:body/w:section[@id = 'extra-appendix']/@title"/>: <a href="#schm">Schemas</a><br/>
            </xsl:if>
		</p>
	</xsl:template>	

    <!-- toc ________________________________________________________________ -->

	<xsl:template match="w:section[@id != 'extra-appendix']" mode="toc">
	     <xsl:param name="section_context"></xsl:param>
         <xsl:param name="section_offset">1</xsl:param>
		<xsl:value-of select="$section_context"/><xsl:value-of select="count(preceding-sibling::w:section)+$section_offset"/>. <a href="#{@id}">
			<xsl:value-of select="@title"/>
		</a>
		<br/>
		<xsl:apply-templates select="w:subsection|w:refinement" mode="toc">
		    <xsl:with-param name="section_context"><xsl:value-of select="$section_context"/><xsl:value-of select="count(preceding-sibling::w:section)+$section_offset"/>.</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template match="w:subsection" mode="toc">
	     <xsl:param name="section_context"></xsl:param>
         <xsl:if test="@id != 'claimingconformance'">
           <span class="subtoc">
             <xsl:value-of select="$section_context"/><xsl:value-of select="count(preceding-sibling::w:subsection[@id != 'claimingconformance'])+1"/>. <a href="#{@id}">
             <xsl:value-of select="@title"/>
           </a>
           </span>
		<br/>
		<xsl:apply-templates select="w:subsection|w:refinement" mode="toc">
		    <xsl:with-param name="section_context"><xsl:value-of select="$section_context"/><xsl:value-of select="count(preceding-sibling::w:subsection[@id != 'claimingconformance'])+1"/>.</xsl:with-param>
		</xsl:apply-templates>
      </xsl:if><!-- test claimingconformance -->		
	</xsl:template>

	<xsl:template match="w:refinement" mode="toc">
	     <xsl:param name="section_context"></xsl:param>
		<xsl:if test="@title">
			<span class="subsubtoc">
				<xsl:value-of select="$section_context"/><xsl:value-of select="count(preceding-sibling::w:refinement[@title])+1"/>.<xsl:text> </xsl:text>
				<a href="#{translate(@title, ' :', '__')}">
					<xsl:value-of select="@title"/>
				</a>
			</span>
			<br/>
		</xsl:if> <!-- test="@title" -->
	</xsl:template>

	<xsl:template match="w:editors/w:person">
		<dd>
			<xsl:value-of select="."/>, <xsl:value-of select="@affiliation"/>
			<xsl:if test="@note"> (<xsl:value-of select="@note"/>)</xsl:if> <!-- test="@note" -->
		</dd>
	</xsl:template>

    <!-- front ________________________________________________________ -->

    <xsl:template match="w:front">

        <xsl:apply-templates/>

        <h3 id="conventions">
            <xsl:value-of select="count(//w:front/w:section)"/>.<xsl:value-of select="count(//w:front/w:section[position()=last()]/w:subsection[@id != 'claimingconformance'])+1"/>
            <xsl:text> </xsl:text>
            Notational Conventions
        </h3>

        <p>The keywords "MUST", "MUST NOT", "REQUIRED", "SHALL", "SHALL NOT",
        "SHOULD", "SHOULD NOT", "RECOMMENDED", "MAY", and "OPTIONAL" in this
        document are to be interpreted as described in <a class="offsite"
        href="http://www.ietf.org/rfc/rfc2119.txt">RFC2119</a>.</p>

        <xsl:if test="$has_statements">
          <p>
            Normative statements of requirements in <xsl:value-of select='$profileref_the' />
            (i.e., those impacting conformance, as outlined in "<a
            href="#conformance_requirements">Conformance Requirements</a>") are presented in the
            following manner:
          </p>

          <p class="statement">
            <span class="statement-id">Rnnnn</span>Statement text here.
          </p>

          <p>
            where "nnnn" is replaced by a number that is unique among the requirements in
            <xsl:value-of select='$profileref_the' />, thereby forming a unique requirement
            identifier.
          </p>

          <p>
            Requirements can be considered to be namespace qualified, in such a way as to be
            compatible with QNames from <a class="offsite"
            href="http://www.w3.org/TR/REC-xml-names/">Namespaces in XML</a>. If there is no
            explicit namespace prefix on a requirement's identifier (e.g., "R9999" as opposed to
            "bp10:R9999"), it should be interpreted as being in the namespace identified for this
            Profile.
          </p>

          <!-- Removed as part of the resolution to BP 12082/20165
               <p>Some requirements clarify the referenced specification(s), but do not
               place additional constraints upon implementations. For convenience,
               clarifications are annotated in the following manner: <span
               class="statement-type">C</span></p>

              <p>Some requirements are derived from ongoing standardization work on
              the referenced specification(s). For convenience, such forward-derived
              statements are annotated in the following manner: <span
              class="statement-origin">xxxx</span>, where "xxxx" is an identifier
              for the specification (e.g., "WSDL20" for WSDL Version 2.0). Note that
              because such work was not complete when this document was published,
              the specification that the requirement is derived from may change;
              this information is included only as a convenience to
              implementers.</p>
			
              <p>As noted above, some requirements may present compatibility issues
              (whether forwards or backwards) with previously published versions of the
              profile.  For convenience, such requirements are annotated in the following
              manner: <span class="compat-type">Compat</span></p>
          -->
        </xsl:if> <!-- test="$has_statements" -->

        <xsl:if test="//w:point">
        <p>Extensibility points in underlying specifications (see "<a
        href="#conformance_scope">Conformance Scope</a>") are presented in a similar
        manner:</p>

        <p class="statement"> <span class="statement-id">Ennnn</span>Extensibility
        Point Name - Description</p>

        <p>where "nnnn" is replaced by a number that is unique among the extensibility
        points in <xsl:value-of select='$profileref_the' />. As with requirement statements, extensibility statements
        can be considered namespace-qualified.</p>
        </xsl:if> <!-- test="//w:point" -->

        <!--
        <p>This Profile supports multiple conformance targets. Requirements or sections specific to
        the use of a particular conformance target are annotated in the following manner:
        <span class="claim-type">TARGET</span>.</p>
        -->

        <xsl:if test="//w:head/w:namespaces/w:namespace">
            <p>This specification uses a number of namespace prefixes throughout;
            their associated URIs are listed below. Note that the choice of any
            namespace prefix is arbitrary and not semantically significant.</p>

            <ul>
            <xsl:for-each select="//w:head/w:namespaces/w:namespace">
                <li><strong><xsl:value-of select="@prefix"/></strong> - "<xsl:value-of select="."/>"</li>
            </xsl:for-each>
            </ul>
        </xsl:if> <!-- test="//w:head/w:namespaces/w:namespace" -->

        <xsl:if test="$has_statements">
        <h3 id="versioning">
        <xsl:value-of select="count(//w:front/w:section)"/>.<xsl:value-of select="count(//w:front/w:section[position()=last()]/w:subsection[@id != 'claimingconformance'])+2"/>
        Profile Identification and Versioning
        </h3>

        <p>This document is identified by a name (in this case, <xsl:value-of select="//w:head/w:title"/>) and
        a version number (here, <xsl:value-of select="//w:head/w:version"/>). Together, they identify a
        particular <em>profile instance</em>.</p>

        <p>Version numbers are composed of a major and minor portion, in the form
        "major.minor". They can be used to determine the precedence of a
        profile instance; a higher version number (considering both the major
        and minor components) indicates that an instance is more recent, and
        therefore supersedes earlier instances.</p>

        <p>Instances of profiles with the same name (e.g., "Example
        Profile 1.1" and "Example Profile 5.0") address interoperability
        problems in the same general scope (although some developments may
        require the exact scope of a profile to change between instances).</p>

        <p>One can also use this information to determine whether two instances of
        a profile are backwards-compatible; that is, whether one can assume
        that conformance to an earlier profile instance implies conformance to a later
        one. Profile instances with the same name and major version number (e.g.,
        "Example Profile 1.0" and "Example Profile 1.1") MAY be considered
        compatible. Note that this does not imply anything about compatibility
        in the other direction; that is, one cannot assume that conformance
        with a later profile instance implies conformance to an earlier one.</p>

        <h2 id="conformance">
            <xsl:value-of select="count(//w:front/w:section)+1"/>
            <xsl:text> </xsl:text>
            Profile Conformance
        </h2>

        <p>Conformance to <xsl:value-of select='$profileref_the' /> is defined by adherence to the
        set of <em>requirements</em> defined for a specific
        <em>target</em>, within the <em>scope</em> of the
        Profile. This section explains these terms and describes how
        conformance is defined and used.</p>

        <h3 id="conformance_requirements">
            <xsl:value-of select="count(//w:front/w:section)+1"/>.1
            <xsl:text> </xsl:text>
            Conformance Requirements
        </h3>

        <p>Requirements state the criteria for conformance to the
        Profile. They typically refer to an existing specification and
        embody refinements, amplifications, interpretations and
        clarifications to it in order to improve interoperability. All
        requirements in <xsl:value-of select='$profileref_the' /> are considered normative, and those
        in the specifications it references that are in-scope (see
        "Conformance Scope") should likewise be considered normative.
        When requirements in <xsl:value-of select='$profileref_the' /> and its referenced
        specifications contradict each other, <xsl:value-of select='$profileref_the' />'s
        requirements take precedence for purposes of Profile
        conformance.</p>

        <p>Requirement levels, using <a class="offsite"
        href="http://www.ietf.org/rfc/rfc2119.txt">RFC2119</a> language (e.g.,
        MUST, MAY, SHOULD) indicate the nature of the requirement and its
        impact on conformance. Each requirement is individually identified
        (e.g., R9999) for convenience.</p>

        <p>For example;</p>

        <p class="statement"><span class="statement-id">R9999</span> Any <strong>WIDGET</strong> SHOULD be round in shape.</p>

        <p>
          This requirement is identified by "R9999", applies to the target WIDGET (see below), and
          places a conditional requirement upon widgets.
        </p>

        <p>Each requirement statement contains exactly one requirement level
        keyword (e.g., "MUST") and one conformance target keyword (e.g.,
        "MESSAGE"). The conformance target keyword appears in bold text (e.g. "<b>MESSAGE</b>"). Other conformance targets appearing in non-bold text are being used strictly for their definition and NOT as a conformance target. Additional text may
        be included to illuminate a requirement or group of
        requirements (e.g., rationale and examples); however, prose
        surrounding requirement statements must not be considered in
        determining conformance.</p>

        <p>Definitions of terms in <xsl:value-of select='$profileref_the' /> are considered
        authoritative for the purposes of determining
        conformance.</p>

        <!-- Removed as part of the resolution of BP 12084/21067
        <p>None of the requirements in <xsl:value-of select='$profileref_the' />, regardless of
        their conformance level, should be interpreted as limiting the
        ability of an otherwise conforming implementation to apply
        security countermeasures in response to a real or perceived
        threat (e.g., a denial of service attack).</p>
        -->

        <h3 id="conformance_targets">
            <xsl:value-of select="count(//w:front/w:section)+1"/>.2
            <xsl:text> </xsl:text>
            Conformance Targets
	    </h3>

        <p>Conformance targets identify what artifacts (e.g.,
        SOAP message, WSDL description, UDDI registry data) or
        parties (e.g., SOAP processor, end user) requirements
        apply to. </p>

        <p>This allows for the definition of conformance in
        different contexts, to assure unambiguous interpretation
        of the applicability of requirements, and to allow
        conformance testing of artifacts (e.g., SOAP messages and
        WSDL descriptions) and the behavior of various parties to
        a Web service (e.g., clients and service instances).</p>

        <p>Requirements' conformance targets are physical
        artifacts wherever possible, to simplify testing and avoid
        ambiguity.</p>

        <p>The following conformance targets are used in <xsl:value-of select='$profileref_the' />:</p>

        <ul>
        <xsl:for-each select="//w:head/w:targets/w:target">
            <li>
              <strong><xsl:value-of select="translate(., 'abcdefghijklmnopqrstuvwxyz', 'ABCDEFGHIJKLMNOPQRSTUVWXYZ')"/></strong>
              - <xsl:value-of select="@desc"/>
              <xsl:if test="@src">
                (from
                <xsl:choose>
                    <xsl:when test="@href"><a class="offsite" href="{@href}"><xsl:value-of select="@src"/></a></xsl:when>
                    <xsl:otherwise><xsl:value-of select="@src"/></xsl:otherwise>
                </xsl:choose>)
              </xsl:if> <!-- test="@src" -->
              <xsl:if test="@claims">
                <span class="claim-type"><xsl:value-of select="@claims"/></span>
              </xsl:if>
            </li>
        </xsl:for-each>
        </ul>

        <h3 id="conformance_scope">
            <xsl:value-of select="count(//w:front/w:section)+1"/>.3
            <xsl:text> </xsl:text>
            Conformance Scope
        </h3>

        <p>The scope of <xsl:value-of select='$profileref_the' /> delineates the technologies
        that it addresses; in other words, <xsl:value-of select='$profileref_the' /> only attempts
        to improve interoperability within its own scope.
        Generally, <xsl:value-of select='$profileref_the' />'s scope is bounded by the
        specifications referenced by it.</p>

        <p>The Profile's scope is further refined by extensibility
        points. Referenced specifications often provide extension
        mechanisms and unspecified or open-ended configuration
        parameters; when identified in <xsl:value-of select='$profileref_the' /> as an
        extensibility point, such a mechanism or parameter is
        outside the scope of <xsl:value-of select='$profileref_the' />, and its use or non-use
        is not relevant to conformance.</p>

        <p>Note that <xsl:value-of select='$profileref_the' /> may still place requirements on
        the use of an extensibility point. Also, specific uses of
        extensibility points may be further restricted by other
        profiles, to improve interoperability when used in
        conjunction with <xsl:value-of select='$profileref_the' />.</p>

        <p>Because the use of extensibility points may impair
        interoperability, their use should be negotiated or
        documented in some fashion by the parties to a Web
        service; for example, this could take the form of an
        out-of-band agreement.</p>

        <xsl:if test="$has_references">
        <!-- for BSP, this paragraph needs to be per-claim -->
        <p>The Profile's scope is defined by the referenced
        specifications in <a href="#references">Appendix A</a>,  as refined by the
        extensibility points in <a href="#points">Appendix B</a>.</p>

        <h3 id="conformance_claims">
            <xsl:value-of select="count(//w:front/w:section)+1"/>.4
            <xsl:text> </xsl:text>
            Claiming Conformance
        </h3>
        </xsl:if> <!-- test="$has_references" -->

        <xsl:choose>
          <xsl:when test="not(//w:front/w:section/w:subsection[@id =  'claimingconformance' ])">

        <p>Claims of conformance to <xsl:value-of select='$profileref_the' /> can be made using the following
        mechanisms, as described in <a class="offsite" href="http://www.ws-i.org/Profiles/ConformanceClaims-1.0.html">Conformance Claim Attachment Mechanisms</a>,
        when the applicable Profile requirements associated
        with the listed targets have been met:</p>

        <!-- need something to link to -->
        <ul>
        <xsl:for-each select="//w:head/w:claimAttach/w:attach">
            <li><strong><xsl:value-of select="@name"/></strong> - <xsl:value-of select="translate(., 'abcdefghijklmnopqrstuvwxyz', 'ABCDEFGHIJKLMNOPQRSTUVWXYZ')"/></li>
        </xsl:for-each>
        </ul>

		<xsl:choose>
		  <xsl:when test="//w:head/w:defaultConformanceURI">
			<p>The conformance claim URI for <xsl:value-of select='$profileref_this' /> is "<xsl:value-of select="//w:head/w:defaultConformanceURI"/>"
			  <xsl:choose>
				<xsl:when test="//w:section[@conformanceURI]">, with the following exceptions, which are associated with specific sections:</xsl:when>
				<xsl:otherwise>.</xsl:otherwise>
			  </xsl:choose>
			</p>
		  </xsl:when>
          <xsl:when test="//w:head/w:conformanceNote">
            <p>
              <xsl:apply-templates select="//w:head/w:conformanceNote" mode="text"/>
            </p>
          </xsl:when>
		  <xsl:otherwise>
			<p>This conformance claim URIs for this profile are associated with specific sections:</p>
		  </xsl:otherwise>
		</xsl:choose>
        <xsl:if test="//w:section/@conformanceURI">
            <ul>
            <xsl:for-each select="//w:section[@conformanceURI]">
                <li><a href="#{@id}"><xsl:value-of select="@title"/></a> - "<xsl:value-of select="@conformanceURI"/>"</li>
            </xsl:for-each>
            </ul>
        </xsl:if> <!-- test="//w:section/@conformanceURI" -->

		<!-- This section adds text to Section 3.4 - Claiming Conformance or Basic Security Profile ONLY -->
		<xsl:if test='/w:profile/w:head/w:shortTitle = "BasicSecurityProfile"' >
			<xsl:if test='/w:profile/w:head/w:version = "1.0"' >
			  <p>If a claim of conformance is made as described in CCAM to Basic Security Profile 1.0 ("<xsl:value-of select="//w:head/w:defaultConformanceURI" />"), then the claim MUST also specify which tokens, be they BSP profile tokens or other mutually agreed upon tokens, are supported.</p>
			  <p>The conformance URI for transport level security ("<xsl:value-of select='//w:section[@id="transportsec"]/@conformanceURI' />") can be used in isolation or in combination with other conformance URIs.</p>
            </xsl:if>
			<xsl:if test='/w:profile/w:head/w:version = "1.1"' >
			  <p>If a claim of conformance is made as described in CCAM to Basic Security Profile 1.1 ("<xsl:value-of select="//w:head/w:defaultConformanceURI" />"), then the claim MUST also specify which tokens, be they BSP profile tokens or other mutually agreed upon tokens, are supported.</p>
			  <p>The conformance URI for transport level security ("<xsl:value-of select='//w:section[@id="transportsec"]/@conformanceURI' />") can be used in isolation or in combination with other conformance URIs.</p>
            </xsl:if>
		</xsl:if> <!-- test='/w:profile/w:head/w:shortTitle = "BasicSecurityProfile"' -->
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates select="//w:front/w:section/w:subsection[@id =  'claimingconformance' ]">
              <xsl:with-param name="section_context" select="'2.'"></xsl:with-param>
              <xsl:with-param name="specialcase">true</xsl:with-param>
            </xsl:apply-templates>
          </xsl:otherwise>
        </xsl:choose>
        </xsl:if> <!-- test="$has_statements" -->

    </xsl:template>

    <!-- body _______________________________________________________ -->

	<xsl:template match="w:body">
		<xsl:apply-templates>
		    <xsl:with-param name="section_offset" select="2+$has_statements"/>
		    <xsl:with-param name="specialcase">false</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>

    <!-- sections, subsections and refinements ______________________ -->

	<xsl:template match="w:section">
         <xsl:param name="section_offset">1</xsl:param>
         <xsl:param name="section_context"></xsl:param>
         <xsl:param name="specialcase"></xsl:param>
         <xsl:if test="(not($specialcase ) or $specialcase = 'false' or $specialcase = '') and @id != 'extra-appendix'">
           <h2 id="{@id}">
             <xsl:value-of select="$section_context"/><xsl:value-of select="count(preceding-sibling::w:section)+$section_offset"/>. <xsl:value-of select="@title"/>
           </h2>
         </xsl:if>
         <xsl:apply-templates>
           <xsl:with-param name="section_context"><xsl:value-of select="$section_context"/><xsl:value-of select="count(preceding-sibling::w:section)+$section_offset"/>.</xsl:with-param>
		    <xsl:with-param name="specialcase" select="$specialcase"/>
         </xsl:apply-templates>
		
	</xsl:template>
	
	<xsl:template match="w:section/w:references">
		<p>This section of <xsl:value-of select='$profileref_the'/> incorporates the following
		specifications by reference<xsl:if test='count(w:reference/w:point)>0'>, and defines extensibility points within
		them</xsl:if>:
		</p>
		<ul>
			<xsl:for-each select="w:reference">
				<li>
					<a class="offsite" href="{@href}">
						<xsl:value-of select="@title"/>
					</a>
					<xsl:if test="@description"> - <xsl:value-of select="@description"/>
					</xsl:if>
					<xsl:if test="w:point">
						<br/>Extensibility points:
			               <ul>
							<xsl:for-each select="w:point">
								<li><span class="statement-id" id="{@id}"><xsl:value-of select="@id"/></span> - <xsl:choose>
										<xsl:when test="@href">
											<a class="offsite" href="{@href}">
												<xsl:value-of select="@title"/>
											</a>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="@title"/>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:if test="@description"> - <xsl:value-of select="@description"/>
									</xsl:if>

<!-- CHANGE 7/18 -->
      <xsl:if test="@claims">
        <span class="claim-type"><xsl:value-of select="@claims"/></span>
      </xsl:if>
      <xsl:if test="@testable">
        <span class="testable-type"><xsl:value-of select="@testable"/></span>
      </xsl:if>
      <xsl:if test="@testRef">

<!-- CHANGE 8/25 -->
	      <xsl:call-template name="toggleTAs">
		<xsl:with-param name="talist" select="@testRef"/>
	      </xsl:call-template>
	      <xsl:call-template name="displayTAs">
		<xsl:with-param name="talist" select="@testRef"/>
	      </xsl:call-template>

      </xsl:if>

								</li>
							</xsl:for-each>
						</ul>
					</xsl:if>
				</li>
			</xsl:for-each>
		</ul>
        <p>
          These extensibility points are listed, along with any extensibility points from other
          sections of this Profile, in <a href="#points">Appendix B</a>
        </p>
	</xsl:template>
	
	<xsl:template match="w:subsection">
         <xsl:param name="section_context"></xsl:param>
         <xsl:param name="specialcase"></xsl:param>
         <xsl:if test="@id != 'claimingconformance' and (not($specialcase) or $specialcase = '' or $specialcase != 'true' ) and not(./../@id = 'extra-appendix' )">
           <h3 id="{@id}">
             <xsl:value-of select="$section_context"/><xsl:value-of select="count(preceding-sibling::w:subsection[@id != 'claimingconformance'])+1"/>
             <xsl:text> </xsl:text>
             <xsl:value-of select="@title"/>
           </h3>
		</xsl:if><!-- test claimingconformance -->
        <xsl:if test="$specialcase = 'true'  or  (./../@id != 'extra-appendix' and  @id != 'claimingconformance') ">
          <xsl:apply-templates>
            <xsl:with-param name="section_context"><xsl:value-of select="$section_context"/><xsl:value-of select="count(preceding-sibling::w:subsection[@id != 'claimingconformance'])+1"/>.</xsl:with-param>
          </xsl:apply-templates>

		<xsl:if test="@id = 'tassertions' ">
	<p>Release notes related to the test material included in this document are available here:
		</p>
		<span class="relnotesref-type">
		<a onclick="javascript:toggle(this)">
		  <xsl:attribute name="href">
		    <xsl:text>#rn</xsl:text>
		    <xsl:value-of select="'ReleaseNotes'"/>
		  </xsl:attribute>
		  <xsl:text>TESTING-RELEASE-NOTES</xsl:text>
		</a>
	      </span>

	       <xsl:call-template name="displayReleaseNotes">
		 <xsl:with-param name="rnid" select="'ReleaseNotes'"/>
	      </xsl:call-template>

		</xsl:if>
      </xsl:if>
	</xsl:template>

	<xsl:template match="w:subsection/w:references">
		<p>This section of <xsl:value-of select='$profileref_the'/> incorporates the following
		specifications by reference<xsl:if test='count(w:reference/w:point)>0'>, and defines extensibility points within
		them</xsl:if>:
		</p>
		<ul>
			<xsl:for-each select="w:reference">
				<li>
					<a class="offsite" href="{@href}">
						<xsl:value-of select="@title"/>
					</a>
					<xsl:if test="@description"> - <xsl:value-of select="@description"/>
					</xsl:if>
					<xsl:if test="w:point">
						<br/>Extensibility points:
			               <ul>
							<xsl:for-each select="w:point">
								<li><span class="statement-id" id="{@id}"><xsl:value-of select="@id"/></span> - <xsl:choose>
										<xsl:when test="@href">
											<a class="offsite" href="{@href}">
												<xsl:value-of select="@title"/>
											</a>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="@title"/>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:if test="@description"> - <xsl:value-of select="@description"/>
									</xsl:if>
								</li>
							</xsl:for-each>
						</ul>
					</xsl:if>
				</li>
			</xsl:for-each>
		</ul>
	</xsl:template>
	
	<!--  replaced with template above CBF
	
	<xsl:template match="w:subsection/w:references">
		<p>The following specifications (or sections thereof) are referred to
		in this section of <xsl:value-of select='$profileref_the'/>:</p>
		<ul>
			<xsl:for-each select="w:reference">
				<li>
					<a class="offsite" href="{@href}">
						<xsl:value-of select="@title"/>
					</a>
					<xsl:if test="@description"> - <xsl:value-of select="@description"/>
					</xsl:if>
				</li>
			</xsl:for-each>
		</ul>
	</xsl:template>	
	-->
	
	<xsl:template match="w:refinement">
         <xsl:param name="section_context"></xsl:param>
		<div class="refinement">
			<xsl:if test="@title">
				<h4 id="{translate(@title, ' :', '__')}">
					<xsl:value-of select="$section_context"/><xsl:value-of select="count(preceding-sibling::w:refinement[@title])+1"/>
					<xsl:text> </xsl:text>
					<xsl:value-of select="@title"/>
				</h4>
			</xsl:if>
			<xsl:apply-templates select="w:definedTerm"/>
			<xsl:apply-templates select="w:rationale"/>
			<xsl:apply-templates select="w:statement"/>
			<xsl:apply-templates select="w:practice"/>
			<xsl:apply-templates select="w:explanation"/>
			<xsl:if test="w:example">
				<p class="example-banner">For example,</p>
			</xsl:if>
			<xsl:apply-templates select="w:example"/>
			<xsl:apply-templates select="w:ednote"/>
		</div>
	</xsl:template>
	
	<xsl:template match="w:definedTerm">
			<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="w:term">
		<p>Definition: <xsl:value-of select="."/></p>
	</xsl:template>

	<xsl:template match="w:definition">
		<div class="definition">
			<xsl:choose>
				<xsl:when test="name(./*)!='h:p'">
					<p>
						<xsl:apply-templates mode="text"/>
					</p>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates mode="text"/>
				</xsl:otherwise>
			</xsl:choose>
		</div>
	</xsl:template>

	<xsl:template match="w:statement">
	    <xsl:variable name="taref" select="@testref"/>
		<p class="statement">
			<span class="statement-id">
				<a name="{@id}">
					<xsl:value-of select="@id"/>
<xsl:if test="($this_drafttype='ED')"> 				
<xsl:text> (from issue: </xsl:text>
					<xsl:value-of select="@issue"/>
<xsl:text>)</xsl:text>
</xsl:if> 
				</a>
			</span>
			<xsl:text> </xsl:text>
			<xsl:apply-templates mode="text"/>
			<xsl:if test="@type='clarification'">
				<span class="statement-type">C</span>
			</xsl:if>
			<xsl:if test="@origin">
				<span class="statement-origin">
					<xsl:value-of select="@origin"/>
				</span>
			</xsl:if>
			<xsl:if test="@compat='breaking'">
				<span class="compat-type">Compat</span>
			</xsl:if>
      <xsl:if test="@claims">
        <span class="claim-type"><xsl:value-of select="@claims"/></span>
      </xsl:if>
      <xsl:if test="@testable">
        <span class="testable-type"><xsl:value-of select="@testable"/></span>
      </xsl:if>
      <xsl:if test="@testRef">

	      <xsl:call-template name="toggleTAs">
		<xsl:with-param name="talist" select="@testRef"/>
	      </xsl:call-template>
	      <xsl:call-template name="displayTAs">
		<xsl:with-param name="talist" select="@testRef"/>
	      </xsl:call-template>

      </xsl:if>
		</p>

	</xsl:template>

	<xsl:template match="w:testAssertion">
        <div style="display: none;">
        <xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>

	<xsl:if test="w:analysis">
	  <table border="1" class="tanalysis" width="80%"><tr><th width="20%">Test Assertion Analysis:</th><th align="left"><span class="tanalysis-id">
        <a name="{@id}">
          <xsl:value-of select="@id"/>
        </a>
      </span></th></tr><tr><td>General Notes:</td><td><xsl:value-of select="w:analysis/w:notes"/></td></tr>
			<tr><td>Coverage Assessment:</td><td><xsl:value-of select="w:analysis/w:coverage"/></td></tr>
			<tr><td>Target Type:</td><td><xsl:value-of select="w:analysis/w:targetType"/></td></tr>
			<tr><td>Test Target:</td><td><xsl:value-of select="w:analysis/w:target"/></td></tr>
			<tr><td>Test co-Target(s):</td><td><xsl:value-of select="w:analysis/w:cotarget"/></td></tr>
			<tr><td>Test Prerequisite:</td><td><xsl:value-of select="w:analysis/w:prerequisite"/></td></tr>
			<tr><td>Predicate:</td><td><xsl:value-of select="w:analysis/w:predicate"/></td></tr>
			<tr><td>Prescription:</td><td><xsl:value-of select="w:prescription/@level"/></td></tr>
			<tr><td>Reporting:</td><td><xsl:value-of select="w:analysis/w:reporting"/></td></tr>
			<tr><td>Test Control:</td><td><xsl:value-of select="w:analysis/w:testcontrol"/></td></tr>
		</table>
		<p></p>
	</xsl:if>
		<table border="1" class="assertion" width="80%"><tr><th width="20%">Test Assertion:</th><th align="left"><span class="assertion-id">
        <a name="{@id}">
          <xsl:value-of select="@id"/>
        </a>
      </span></th></tr><tr><td><b>Description:</b></td><td><xsl:copy-of select="w:description"/></td></tr>
			<tr><td><b>Target:</b></td><td><xsl:copy-of select="w:target"/></td></tr>
<xsl:if test="w:cotarget[1]">
			<tr><td><b>co-Target: &#10;</b><xsl:value-of select="w:cotarget[1]/@name"/></td><td><xsl:copy-of select="w:cotarget[1]"/></td></tr>
</xsl:if>
<xsl:if test="w:cotarget[2]">
			<tr><td><b>co-Target: &#10;</b><xsl:value-of select="w:cotarget[2]/@name"/></td><td><xsl:copy-of select="w:cotarget[2]"/></td></tr>
</xsl:if>

<xsl:variable name="ta" select="."/>
<xsl:variable name="preq">

  <xsl:value-of select="$ta/@preReq"/>

  <xsl:if test="$ta/w:prerequisite">
    <xsl:copy-of select="$ta/w:prerequisite"/>
  </xsl:if>
</xsl:variable>

<xsl:if test="$preq != ''">
			<tr>
			  <td><b>Prerequisite:</b></td>
			  <td>
			    <xsl:copy-of select="$preq"/>
			</td>
			</tr>
</xsl:if>
			<tr><td><b>Predicate:</b></td><td><xsl:copy-of select="w:predicate"/></td></tr>
<xsl:choose>
<xsl:when test="w:reporting">
			<tr><td><b>Reporting:</b></td><td>
			    <xsl:text> true=</xsl:text><xsl:value-of select="w:reporting/@true"/>
			    <xsl:text>, false=</xsl:text><xsl:value-of select="w:reporting/@false"/>
			</td></tr>
</xsl:when>
<xsl:otherwise>
			<tr><td><b>Reporting:</b></td>
			  <td> <xsl:text>true=passed, false=failed</xsl:text></td>
			</tr>
</xsl:otherwise>
</xsl:choose>

			<tr><td><b>Prescription:</b></td><td><xsl:value-of select="w:prescription/@level"/></td></tr>
			<tr><td><b>Error Message:</b></td><td><xsl:copy-of select="w:errorMessage"/></td></tr>
	                <tr><td><b>Diagnostic Data:</b></td><td><xsl:copy-of select="w:diagnostic"/></td></tr>
		</table>
	</div>
	</xsl:template>
	

	<xsl:template name="displayOneTA">
	  <xsl:param name="ta"/>

        <div style="display: none;">
        <xsl:attribute name="id"><xsl:value-of select="$ta/@id"/></xsl:attribute>

	<xsl:if test="$ta/w:analysis">
	  <table border="1" class="tanalysis" width="80%"><tr><th width="20%">Test Assertion Analysis:</th><th align="left"><span class="tanalysis-id">
        <a name="{$ta/@id}">
          <xsl:value-of select="$ta/@id"/>
        </a>
      </span></th></tr><tr><td>General Notes:</td><td><xsl:value-of select="$ta/w:analysis/w:notes"/></td></tr>
			<tr><td>Coverage Assessment:</td><td><xsl:value-of select="$ta/w:analysis/w:coverage"/></td></tr>
			<tr><td>Target Type:</td><td><xsl:value-of select="$ta/w:analysis/w:targetType"/></td></tr>
			<tr><td>Test Target:</td><td><xsl:value-of select="$ta/w:analysis/w:target"/></td></tr>
			<tr><td>Test co-Target(s):</td><td><xsl:value-of select="$ta/w:analysis/w:cotarget"/></td></tr>
			<tr><td>Test Prerequisite:</td><td><xsl:value-of select="$ta/w:analysis/w:prerequisite"/></td></tr>
			<tr><td>Predicate:</td><td><xsl:value-of select="$ta/w:analysis/w:predicate"/></td></tr>
			<tr><td>Prescription:</td><td><xsl:value-of select="$ta/w:prescription/@level"/></td></tr>
			<tr><td>Reporting:</td><td><xsl:value-of select="$ta/w:analysis/w:reporting"/></td></tr>
			<tr><td>Test Control:</td><td><xsl:value-of select="$ta/w:analysis/w:testcontrol"/></td></tr>
		</table>
		<p></p>
	</xsl:if>
		<table border="1" class="assertion" width="80%"><tr><th width="20%">Test Assertion:</th><th align="left"><span class="assertion-id">
        <a name="{$ta/@id}">
          <xsl:value-of select="$ta/@id"/>
        </a>
      </span></th></tr><tr><td><b>Description:</b></td><td><xsl:value-of select="$ta/w:description"/></td></tr>
			<tr><td><b>Target:</b></td><td><xsl:copy-of select="$ta/w:target"/></td></tr>
<xsl:if test="$ta/w:cotarget[1]">
			<tr><td><b>co-Target: &#10;</b><xsl:value-of select="$ta/w:cotarget[1]/@name"/></td><td><xsl:copy-of select="$ta/w:cotarget[1]"/></td></tr>
</xsl:if>
<xsl:if test="$ta/w:cotarget[2]">
			<tr><td><b>co-Target: &#10;</b><xsl:value-of select="$ta/w:cotarget[2]/@name"/></td><td><xsl:copy-of select="$ta/w:cotarget[2]"/></td></tr>
</xsl:if>

<xsl:variable name="preq">

  <xsl:value-of select="$ta/@preReq"/>

  <xsl:if test="$ta/w:prerequisite">
    <xsl:copy-of select="$ta/w:prerequisite"/>
  </xsl:if>
</xsl:variable>

<xsl:if test="$preq != ''">
			<tr>
			  <td><b>Prerequisite:</b></td>
			  <td>
			    <xsl:copy-of select="$preq"/>
			</td>
			</tr>
</xsl:if>

			<tr><td><b>Predicate:</b></td><td><xsl:copy-of select="$ta/w:predicate"/></td></tr>

<xsl:choose>
<xsl:when test="$ta/w:reporting">
			<tr><td><b>Reporting:</b></td><td>
			    <xsl:text> true=</xsl:text><xsl:value-of select="$ta/w:reporting/@true"/>
			    <xsl:text>, false=</xsl:text><xsl:value-of select="$ta/w:reporting/@false"/>
			</td></tr>
</xsl:when>
<xsl:otherwise>
			<tr><td><b>Reporting:</b></td>
			  <td> <xsl:text>true=passed, false=failed</xsl:text></td>
			</tr>
</xsl:otherwise>
</xsl:choose>

			<tr><td><b>Prescription:</b></td><td><xsl:value-of select="$ta/w:prescription/@level"/></td></tr>
			<tr><td><b>Error Message:</b></td><td><xsl:value-of select="$ta/w:errorMessage"/></td></tr>
	                <tr><td><b>Diagnostic Data:</b></td><td><xsl:copy-of select="$ta/w:diagnostic"/></td></tr>
		</table>

		<span class="glossaryref-type">
		<a onclick="javascript:toggle(this)">
		  <xsl:attribute name="href">
		    <xsl:text>#glossary</xsl:text>
		    <xsl:value-of select="$ta/@id"/>
		  </xsl:attribute>
		  <xsl:text>HELP - GLOSSARY</xsl:text>
		</a>
	      </span>

	</div>

	       <xsl:call-template name="displayTAglossary">
		 <xsl:with-param name="taid" select="$ta/@id"/>
	      </xsl:call-template>

	</xsl:template>


	<xsl:template name="displayTAglossary">
	  <xsl:param name="taid"/>

          <div style="display: none;">
        <xsl:attribute name="id"><xsl:value-of select="concat('glossary', $taid)"/></xsl:attribute>
        <!-- xsl:attribute name="id">glossary</xsl:attribute -->

	    <table border="1" class="taglossary" width="80%"><tr><th width="20%">Test Assertion Part</th><th align="left">
		  <span class="taglossary-id">
		    <!-- a name="{$ta/@id}">
		    <xsl:value-of select="$ta/@id"/>
		    </a -->
		    <a name="glossary">
		    <xsl:value-of select="'What it means:'"/>
		    </a>
	      </span>
	      </th></tr>
	      <tr><td><b>Test Assertion ID:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'TA_Id']"/></td></tr>
	      <tr><td><b>Description:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'description']"/></td></tr>
	      <tr><td><b>Comments:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'comments']"/></td></tr>
	      <tr><td><b>Target:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'target']"/></td></tr>
	      <tr><td><b>Cotarget:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'cotarget']"/></td></tr>
	      <tr><td><b>Prerequisite:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'prerequisite']"/></td></tr>
	      <tr><td><b>Predicate:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'predicate']"/></td></tr>
	      <tr><td><b>Prescription:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'prescription']"/></td></tr>
	      <tr><td><b>Reporting:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'reporting']"/></td></tr>
	    </table>
	    <p></p>

	  </div>

	</xsl:template>

	<xsl:template name="displayReleaseNotes">
	  <xsl:param name="rnid"/>

          <div style="display: none;">
        <!-- xsl:attribute name="id"><xsl:value-of select="concat('glossary', $taid)"/></xsl:attribute -->
        <xsl:attribute name="id">rnReleaseNotes</xsl:attribute>

	    <table border="1" class="tablernotes" width="80%"><tr><th width="20%">Note Item:</th><th align="left">
		  <span class="tbrnotes-id">
		    <a name="rn">
		    <xsl:value-of select="concat('Release Notes : ', //w:testAssertions/w:releaseNotes/@releasedate )"/>
		    </a>
	      </span>
	      </th></tr>
	      <tr>
		<td><b>test suite</b></td>
		<td><xsl:copy-of select="//w:testAssertions/w:releaseNotes/w:item[@name = 'test-suite']"/></td>
	      </tr>
	      <tr>
		<td><b>test assertions notes</b></td>
		<td><xsl:copy-of select="//w:testAssertions/w:releaseNotes/w:item[@name = 'test-assertions-notes']"/></td>
	      </tr>
	      <tr>
		<td><b>test log rules</b></td>
		<td><xsl:copy-of select="//w:testAssertions/w:releaseNotes/w:item[@name = 'test-log-rules']"/></td>
	      </tr>
	    </table>
	    <p></p>

	  </div>

	</xsl:template>
	

	<xsl:template match="w:rationale">
		<div class="rationale">
			<xsl:choose>
				<xsl:when test="name(./*)!='h:p'">
					<p>
						<xsl:apply-templates mode="text"/>
					</p>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates mode="text"/>
				</xsl:otherwise>
			</xsl:choose>
		</div>
	</xsl:template>

	<xsl:template match="w:practice">
		<div class="practice">
			<xsl:choose>
				<xsl:when test="name(./*)!='h:p'">
					<p>
						<xsl:apply-templates mode="text"/>
					</p>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates mode="text"/>
				</xsl:otherwise>
			</xsl:choose>
		</div>
	</xsl:template>

	<xsl:template match="w:explanation">
		<div class="explanation">
			<xsl:choose>
				<xsl:when test="name(./*)!='h:p'">
					<p>
						<xsl:apply-templates mode="text"/>
					</p>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates mode="text"/>
				</xsl:otherwise>
			</xsl:choose>
		</div>
	</xsl:template>

	<xsl:template match="w:example">
		<div class="example">
			<xsl:choose>
				<xsl:when test="@correct='1'">
					<p class="correct">CORRECT: </p>
				</xsl:when>
				<xsl:when test="@correct='0'">
					<p class="incorrect">INCORRECT: </p>
				</xsl:when>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="@block='1'">
					<pre>
						<xsl:value-of select="."/>
					</pre>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="name(./*)!='h:p'">
							<p>
								<xsl:apply-templates mode="text"/>
							</p>
						</xsl:when>
						<xsl:otherwise>
							<xsl:apply-templates mode="text"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</div>
	</xsl:template>

	<xsl:template match="w:ednote">
		<xsl:if test="//w:status!='Final'">
			<p class="ednote">
				<strong>Editors' note:</strong>
				<xsl:value-of select="."/>
			</p>
		</xsl:if>
	</xsl:template>

    <!-- trailer ___________________________________________________ -->

    <xsl:template name="trailer">
      <xsl:if test="$has_references">
        <h2 id="references">Appendix A: Referenced Specifications</h2>
        <p>
          The following specifications' requirements are incorporated into <xsl:value-of
          select='$profileref_the' /> by reference, except where superseded by the Profile:
        </p>
        <ul>
          <xsl:apply-templates select="//w:references" mode="references"/>
        </ul>
        <xsl:if test="$has_bibrefs">
          <p>
            The following specifications are also referenced by <xsl:value-of select='$profileref_the' />:
          </p>
          <ul>
            <xsl:apply-templates select="//w:references/w:bibref" mode="references"/>
          </ul>				
        </xsl:if>
        <h2 id="points">Appendix B: Extensibility Points</h2>
        <p>
          This section identifies extensibility points, as defined in "Scope of <xsl:value-of
          select='$profileref_the' />," for <xsl:value-of select='$profileref_the' />'s component
          specifications.
        </p>
        <p>
          These mechanisms are out of the scope of <xsl:value-of select='$profileref_the'/> and
          Profile conformance. An initial, non-exhaustive list of these extensibility points is
          provided here as their use may affect interoperability. In order to avoid
          interoperability issues not addressed by the Profile, out-of-band agreement on the use of
          these extensibility points may be necessary between the parties to a Web service.
        </p>
        <xsl:apply-templates select="//w:references" mode="points"/>
        <h2 id="normative_references">Appendix C: Normative References</h2>
        <p>
          In addition to all of the profiled specifications listed in Appendix A, the following
          specifications are normatively referenced:
        </p>
        <p>
          RFC2119 <a href="http://ietf.org/rfc/rfc2119">http://ietf.org/rfc/rfc2119</a> Key words
          for use in RFCs to Indicate Requirement Levels, S. Bradner March 1997
        </p>
        <p>
          Namespaces in XML 1.0 (Second Edition) <a
          href="http://www.w3.org/TR/REC-xml-names/">http://www.w3.org/TR/REC-xml-names/</a>
          T. Bray et al August 2006
        </p>
        <p>
          WS-I Conformance Claim Attachment Mechanisms Version 1.0 <a
          href="http://www.ws-i.org/Profiles/ConformanceClaims-1.0-2004-11-15.html">http://www.ws-i.org/Profiles/ConformanceClaims-1.0-2004-11-15.html</a>,
          M. Nottingham et al November 2004
        </p>
        <xsl:if test="not(/w:profile/w:head/w:shortTitle='BasicProfile')">
        <p>
          WS-I Basic Profile 1.2
          <a href="http://www.ws-i.org/Profiles/BasicProfile-1.2.html">
            http://www.ws-i.org/Profiles/BasicProfile-1.2.html
          </a>,
          G. Pilz et al September 2010
        </p>
        <p>
          WS-I Basic Profile 2.0
          <a href="http://www.ws-i.org/Profiles/BasicProfile-2.0.html">
            http://www.ws-i.org/Profiles/BasicProfile-2.0.html
          </a>,
          G. Pilz et al September 2010
        </p>
        </xsl:if>
        <xsl:if test="(/w:profile/w:head/w:shortTitle='ReliableSecureProfile')">
        <p>
          WS-I Basic Security Profile 1.0
          <a href="http://www.ws-i.org/Profiles/BasicSecurityProfile-1.0-2007-03-30.html">
            http://www.ws-i.org/Profiles/BasicSecurityProfile-1.0-2007-03-30.html
          </a>,
          M. McIntosh et al March 2007
        </p>
        <p>
          WS-I Basic Security Profile 1.1
          <a href="http://www.ws-i.org/Profiles/BasicSecurityProfile-1.1.html">
            http://www.ws-i.org/Profiles/BasicSecurityProfile-1.1.html
          </a>,
          M. McIntosh et al January 2010
        </p>
        </xsl:if>
      </xsl:if>
      <xsl:if test="not($has_references)">
        <h2 id="normative_references">Appendix A: Normative References</h2>
        <p>
          The following specifications are normatively referenced:
        </p>
        <p>
          RFC2119 <a href="http://ietf.org/rfc/rfc2119">http://ietf.org/rfc/rfc2119</a> Key words
          for use in RFCs to Indicate Requirement Levels, S. Bradner March 1997
        </p>
        <p>
          Namespaces in XML 1.0 (Second Edition) <a
          href="http://www.w3.org/TR/REC-xml-names/">http://www.w3.org/TR/REC-xml-names/</a>
          T. Bray et al August 2006
        </p>
        <p>
          WS-I Conformance Claim Attachment Mechanisms Version 1.0 <a
          href="http://www.ws-i.org/Profiles/ConformanceClaims-1.0-2004-11-15.html">http://www.ws-i.org/Profiles/ConformanceClaims-1.0-2004-11-15.html</a>,
          M. Nottingham et al November 2004
        </p>
        <xsl:if test="not(/w:profile/w:head/w:shortTitle='BasicProfile')">
        <p>
          WS-I Basic Profile 1.2
          <a href="http://www.ws-i.org/Profiles/BasicProfile-1.2.html">
            http://www.ws-i.org/Profiles/BasicProfile-1.2.html
          </a>,
          G. Pilz et al September 2010
        </p>
        <p>
          WS-I Basic Profile 2.0
          <a href="http://www.ws-i.org/Profiles/BasicProfile-2.0.html">
            http://www.ws-i.org/Profiles/BasicProfile-2.0.html
          </a>,
          G. Pilz et al September 2010
        </p>
        </xsl:if>
        <xsl:if test="(/w:profile/w:head/w:shortTitle='ReliableSecureProfile')">
        <p>
          WS-I Basic Security Profile 1.0
          <a href="http://www.ws-i.org/Profiles/BasicSecurityProfile-1.0-2007-03-30.html">
            http://www.ws-i.org/Profiles/BasicSecurityProfile-1.0-2007-03-30.html
          </a>,
          M. McIntosh et al March 2007
        </p>
        <p>
          WS-I Basic Security Profile 1.1
          <a href="http://www.ws-i.org/Profiles/BasicSecurityProfile-1.1.html">
            http://www.ws-i.org/Profiles/BasicSecurityProfile-1.1.html
          </a>,
          M. McIntosh et al January 2010
        </p>
        </xsl:if>
      </xsl:if>
      <xsl:if test="//w:definedTerm">
        <h2 id="defs">Appendix <xsl:value-of select="translate(($has_references*2)+2, '12345', 'ABCDE')"/>: Defined Terms</h2>
        <p>
          The following list of terms have specific definitions that are authoritative for this
          profile:
        </p>
        <dl>
          <xsl:for-each select="//w:definedTerm">
            <dt><xsl:value-of select="w:term"/></dt>
            <dd><xsl:apply-templates select="w:definition"/></dd>
          </xsl:for-each>
        </dl>
      </xsl:if>
      <h2 id="acks">Appendix <xsl:value-of select="translate(($has_references*2)+boolean(//w:definedTerm/w:term)+2, '12345', 'ABCDE')"/>: Acknowledgements</h2>
      <p>
        This document is the work of the WS-I <xsl:value-of select="//w:head/w:wgName"/> Working
        Group.
      </p>
      <p>
        <xsl:apply-templates select="//w:contributorText"/>
      </p>
      <xsl:if test="//w:body/w:section[@id = 'extra-appendix']">
        <h2 id="schm">Appendix <xsl:value-of select="//w:body/w:section[@id = 'extra-appendix']/@title"/>: Schemas</h2>
        <xsl:apply-templates select="//w:body/w:section[@id = 'extra-appendix']">
          <xsl:with-param name="specialcase">true</xsl:with-param>
        </xsl:apply-templates>
      </xsl:if>
    </xsl:template>

    <!-- acknowledgements _________________________________________________ -->

    <xsl:template match="//w:contributorText">
        <xsl:choose>
            <xsl:when test="@href">
              <p> Members have included:</p>
              <xsl:value-of select="document(@href, /)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="."/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- referenced specifications ________________________________________ -->

	<xsl:template match="//w:references" mode="references">
		<xsl:for-each select="w:reference[not(@title=preceding::w:reference/@title)]">
			<li>
				<a class="offsite" href="{@href}">
					<xsl:value-of select="@title"/>
				</a>
				<xsl:if test="@description"> - <xsl:value-of select="@description"/>
				</xsl:if>
			</li>
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="//w:references/w:bibref" mode="references">
	  <li>
		<a class="offsite" href="{@href}">
		  <xsl:value-of select="@title"/>
		</a>
		<xsl:if test="@description"> - <xsl:value-of select="@description"/>
	  </xsl:if>
	</li>
	</xsl:template>

    <!-- extensibility points ___________________________________________ -->

	<xsl:template match="//w:references" mode="points">
		<xsl:for-each select="w:reference[not(@title=preceding::w:reference/@title)]">
			<xsl:if test="w:point">
				<p>In <a class="offsite" href="{@href}">
						<xsl:value-of select="@title"/>:</a>
				</p>
				<ul>
					<xsl:for-each select="w:point">
						<li><span class="statement-id"><xsl:value-of select="@id"/></span> - <xsl:choose>
								<xsl:when test="@href">
									<strong>
										<a class="offsite" href="{@href}">
											<xsl:value-of select="@title"/>
										</a>
									</strong>
								</xsl:when>
								<xsl:otherwise>
									<strong>
										<xsl:value-of select="@title"/>
									</strong>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:if test="@description"> - <xsl:value-of select="@description"/>
							</xsl:if>

      <xsl:if test="@claims">
        <span class="claim-type"><xsl:value-of select="@claims"/></span>
      </xsl:if>
      <xsl:if test="@testable">
        <span class="testable-type"><xsl:value-of select="@testable"/></span>
      </xsl:if>
      <xsl:if test="@testRef">

	      <xsl:call-template name="toggleTAs">
		<xsl:with-param name="talist" select="@testRef"/>
	      </xsl:call-template>
	      <xsl:call-template name="displayTAs">
		<xsl:with-param name="talist" select="@testRef"/>
	      </xsl:call-template>


      </xsl:if>
						</li>
					</xsl:for-each>
				</ul>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

     <!-- text formatting _______________________________________________________ -->

	<xsl:template match="w:text">
		<xsl:apply-templates mode="text"/>
	</xsl:template>

	<xsl:template match="h:p" mode="text">
		<xsl:element name="p">
			<xsl:if test="@class">
				<xsl:attribute name="class"><xsl:value-of select="@class"/></xsl:attribute>
			</xsl:if>
			<xsl:apply-templates mode="text"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="h:pre" mode="text">
		<xsl:element name="pre">
			<xsl:if test="@class">
				<xsl:attribute name="class"><xsl:value-of select="@class"/></xsl:attribute>
			</xsl:if>
			<xsl:apply-templates mode="text"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="h:ol" mode="text">
		<ol type="{@type}">
			<xsl:apply-templates mode="text"/>
		</ol>
	</xsl:template>
	<xsl:template match="h:ul" mode="text">
		<ul>
			<xsl:apply-templates mode="text"/>
		</ul>
	</xsl:template>
	<xsl:template match="h:li" mode="text">
		<li>
			<xsl:apply-templates mode="text"/>
		</li>
	</xsl:template>
	<xsl:template match="h:dl" mode="text">
		<dl>
			<xsl:apply-templates mode="text"/>
		</dl>
	</xsl:template>
	<xsl:template match="h:dt" mode="text">
		<dt>
			<xsl:apply-templates mode="text"/>
		</dt>
	</xsl:template>
	<xsl:template match="h:dd" mode="text">
		<dd>
			<xsl:apply-templates mode="text"/>
		</dd>
	</xsl:template>
	<xsl:template match="w:span" mode="text">
		<span class="{@class}">
			<xsl:apply-templates mode="text"/>
		</span>
	</xsl:template>
	<xsl:template match="h:span" mode="text">
		<span class="{@class}">
			<xsl:apply-templates mode="text"/>
		</span>
	</xsl:template>
	<xsl:template match="h:em" mode="text">
		<em>
			<xsl:apply-templates mode="text"/>
		</em>
	</xsl:template>
	<xsl:template match="h:strong" mode="text">
		<strong>
			<xsl:apply-templates mode="text"/>
		</strong>
	</xsl:template>
	<xsl:template match="h:code" mode="text">
		<code>
			<xsl:apply-templates mode="text"/>
		</code>
	</xsl:template>
	<xsl:template match="h:a" mode="text">
		<a class="offsite" href="{@href}">
			<xsl:apply-templates mode="text"/>
		</a>
	</xsl:template>
	<xsl:template match="h:img" mode="text">
	  <img src="{@src}" />
	</xsl:template>
	<xsl:template match='text()' mode='text' >
	  <xsl:variable name='target' select='translate(ancestor::w:statement/@target,"abcdefghijklmnopqrstuvwxyz", "ABCDEFGHIJKLMNOPQRSTUVWXYZ")' />
	  <xsl:choose>
		<xsl:when test='contains(., $target)' >
		  <xsl:value-of select='substring-before(., $target)' />
		  <span class='statement-target' ><xsl:value-of select='$target' /></span>
		  <xsl:value-of select='substring-after(., $target)' />
		</xsl:when>
		<xsl:otherwise>
		  <xsl:value-of select='.' />
		</xsl:otherwise>
	  </xsl:choose>
	</xsl:template>

	<xsl:template name="toggleTAs">
	  <xsl:param name="talist"/>
	  <xsl:choose>
	    <xsl:when test="contains($talist, ' ')">
              <span class="testref-type">
		<a onclick="javascript:toggle(this)">
		  <xsl:attribute name="href">
		    <xsl:text>#</xsl:text>
		    <xsl:value-of select="substring-before($talist,' ')"/>
		  </xsl:attribute>
		  <xsl:value-of select="substring-before($talist,' ')"/>
		</a>
	      </span>
	      <xsl:call-template name="toggleTAs">
		<xsl:with-param name="talist" select="substring-after($talist,' ')"/>
	      </xsl:call-template>
	    </xsl:when>
	    <xsl:otherwise>
              <span class="testref-type">
		<a onclick="javascript:toggle(this)">
		  <xsl:attribute name="href">
		    <xsl:text>#</xsl:text>
		    <xsl:value-of select="$talist"/>
		  </xsl:attribute>
		  <xsl:value-of select="$talist"/>
		</a>
	      </span>
	    </xsl:otherwise>
	  </xsl:choose>
	</xsl:template>

	<xsl:template name="displayTAs">
	  <xsl:param name="talist"/>
	  <xsl:choose>
	    <xsl:when test="contains($talist, ' ')">
		<!-- xsl:apply-templates select="following-sibling::w:testAssertion[@id = substring-before($talist,',')]"/ -->
		<xsl:call-template name="displayOneTA">
		<xsl:with-param name="ta" select="//w:profile/w:testAssertions/w:testAssertion[@id = substring-before($talist,' ')]"/>
	      </xsl:call-template>
	      <xsl:call-template name="displayTAs">
		<xsl:with-param name="talist" select="substring-after($talist,' ')"/>
	      </xsl:call-template>
	    </xsl:when>
	    <xsl:otherwise>
		<xsl:call-template name="displayOneTA">
		<xsl:with-param name="ta" select="//w:profile/w:testAssertions/w:testAssertion[@id = $talist]"/>
	      </xsl:call-template>
		<!-- xsl:apply-templates select="following-sibling::w:testAssertion[@id = $talist]"/ -->
	    </xsl:otherwise>
	  </xsl:choose>
	</xsl:template>


</xsl:stylesheet>
