<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xalan="http://xml.apache.org/xslt"
    xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/"
    xmlns:wsil="http://www.ws-i.org/testing/2008/02/log/"
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xmlns:xsd="http://www.w3.org/2001/XMLSchema"
    exclude-result-prefixes="xalan"
    version="1.0">
  <xsl:output method="xml" encoding="UTF-8" indent="yes" xalan:indent-amount="2"/>
  <xsl:strip-space elements="*"/>

  <xsl:param name="descriptionFile" />

  <!-- root template  -->
  <xsl:template match="/">
    <xsl:apply-templates select="wsil:testLog" mode="LogMAP"/>
  </xsl:template>

  <!-- This rule represents an element mapping: "in:log" to "wsil:testLog".  -->
  <xsl:template match="wsil:testLog"  mode="LogMAP">
    <wsil:testLog>
      <xsl:copy-of select="wsil:messageLog"></xsl:copy-of>
      <xsl:call-template name="descriptionFiles" />          
    </wsil:testLog>
  </xsl:template>
  
  <xsl:template name="descriptionFiles">
  	<xsl:variable name="file" select="document($descriptionFile)" />
  	<wsil:descriptionFiles>
  	  <xsl:apply-templates select="$file/wsdl:definitions">
  	    <xsl:with-param name="filename" select="$descriptionFile" />
  	  </xsl:apply-templates>
  	</wsil:descriptionFiles>
  </xsl:template>
  
  <xsl:template match="wsdl:definitions">
  	<xsl:param name="filename" />
  	<!-- TODO These attributes should be determined programmatically.  -->  
  	<wsil:descriptionFile validXml="true" xmlVersion="1.0" schemaValid="true" encoding="utf-8">
  		<xsl:attribute name="filename"><xsl:value-of select="$filename"/></xsl:attribute>
        <xsl:copy-of select="current()" />  	
  	</wsil:descriptionFile>
  	<xsl:for-each select="wsdl:import">
  	  <xsl:variable name="fileImport" select="@location" />
  	  <xsl:variable name="file" select="document($fileImport)" />  	  
  	  <xsl:apply-templates select="$file/wsdl:definitions">
  	    <xsl:with-param name="filename" select="$fileImport" />
  	  </xsl:apply-templates>  	  
  	</xsl:for-each>  	
  	<xsl:for-each select="wsdl:types/xsd:schema/xsd:import">
  	  <xsl:variable name="fileImport" select="@schemaLocation" />
  	  <xsl:variable name="file" select="document($fileImport)" />  	  
  	  <xsl:apply-templates select="$file/xsd:schema">
  	    <xsl:with-param name="filename" select="$fileImport" />
  	  </xsl:apply-templates>  	  
  	</xsl:for-each>
  </xsl:template>
  
  <xsl:template match="xsd:schema">
  	<xsl:param name="filename" />  
  	<!-- TODO These attributes should be determined programmatically.  -->    	
  	<wsil:descriptionFile validXml="true" xmlVersion="1.0" schemaValid="true" encoding="utf-8">
  		<xsl:attribute name="filename"><xsl:value-of select="$filename"/></xsl:attribute>
        <xsl:copy-of select="current()" />  	
  	</wsil:descriptionFile>
  	<xsl:for-each select="xsd:import">
  	  <xsl:variable name="fileImport" select="@schemaLocation" />
  	  <xsl:variable name="file" select="document($fileImport)" />  	  
  	  <xsl:apply-templates select="$file/xsd:schema">
  	    <xsl:with-param name="filename" select="$fileImport" />
  	  </xsl:apply-templates>  	  
  	</xsl:for-each>
  	<xsl:for-each select="xsd:include">
  	  <xsl:variable name="fileInclude" select="@schemaLocation" />
  	  <xsl:variable name="file" select="document($fileInclude)" />  	  
  	  <xsl:apply-templates select="$file/xsd:schema">
  	    <xsl:with-param name="filename" select="$fileInclude" />
  	  </xsl:apply-templates>  	  
  	</xsl:for-each>  	
  </xsl:template>  

  <!-- *****************    Utility Templates    ******************  -->
  <!-- copy the namespace declarations from the source to the target -->
  <xsl:template name="copyNamespaceDeclarations">
    <xsl:param name="root"/>
    <xsl:for-each select="$root/namespace::*">
      <xsl:copy/>
    </xsl:for-each>
  </xsl:template>
</xsl:stylesheet>

